@@ -4,7 +4,7 @@ written by Michael Stroeder <michael@stroeder.com>
 
 See http://python-ldap.sourceforge.net for details.
 
-\$Id: async.py,v 1.22 2005/06/21 14:59:47 stroeder Exp $
+\$Id: async.py,v 1.25 2006/04/10 05:19:09 stroeder Exp $
 
 Python compability note:
 Tested on Python 2.0+ but should run on Python 1.5.x.
@@ -82,7 +82,7 @@ class AsyncSearchHandler:
         See parameter attrsonly of method LDAPObject.search()
     timeout
         Maximum time the server shall use for search operation
-    sizeLimit
+    sizelimit
         Maximum number of entries a server should return
         (request client-side limit)
     serverctrls
@@ -181,6 +181,47 @@ class List(AsyncSearchHandler):
     self.allResults.append((resultType,resultItem))
 
 
+class Dict(AsyncSearchHandler):
+  """
+  Class for collecting all search results into a dictionary {dn:entry}
+  """
+
+  def __init__(self,l):
+    AsyncSearchHandler.__init__(self,l)
+    self.allEntries = {}
+
+  def _processSingleResult(self,resultType,resultItem):
+    if _entryResultTypes.has_key(resultType):
+      # Search continuations are ignored
+      dn,entry = resultItem
+      self.allEntries[dn] = entry
+
+
+class IndexedDict(Dict):
+  """
+  Class for collecting all search results into a dictionary {dn:entry}
+  and maintain case-sensitive equality indexes to entries
+  """
+
+  def __init__(self,l,indexed_attrs=None):
+    Dict.__init__(self,l)
+    self.indexed_attrs = indexed_attrs or tuple()
+    self.index = {}.fromkeys(self.indexed_attrs,{})
+
+  def _processSingleResult(self,resultType,resultItem):
+    if _entryResultTypes.has_key(resultType):
+      # Search continuations are ignored
+      dn,entry = resultItem
+      self.allEntries[dn] = entry
+      for a in self.indexed_attrs:
+	if entry.has_key(a):
+	  for v in entry[a]:
+	    try:
+    	      self.index[a][v].append(dn)
+	    except KeyError:
+    	      self.index[a][v] = [ dn ]
+
+
 class FileWriter(AsyncSearchHandler):
   """
   Class for writing a stream of LDAP search results to a file object
